/* Copyright (C) 2013 Artyom V. Poptsov <poptsov.artyom@gmail.com>
 *
 * This file is part of Guile-SSH.
 *
 * Guile-SSH is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Guile-SSH is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Guile-SSH.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __THREADS_H__
#define __THREADS_H__

#if ! HAVE_LIBSSH_0_8

#define SSH_PTHREADS_DISABLED 0
#define SSH_PTHREADS_ENABLED  1
void init_pthreads (void);

#else

#define init_pthreads()

#endif  /* if ! HAVE_LIBSSH_0_8 */

#endif  /* ifndef __THREADS_H__ */
